import joi from '@hapi/joi';
import globals from '../../globals';

export default class UserValidate {  // validate input for user
  private static user = {
    _id: joi.any(),
    name: joi.string()
      .alphanum()
      .lowercase(),

    email: joi.string()
      .email({minDomainSegments: 2})
      .lowercase(),

    pass: joi.string()
      .pattern(new RegExp('^(?=.*[0-9])(?=.*[a-z])(?=.*[A-Z])(?=.*[!"#%&\'()*+,-.\\/:;<=>?@[\\]^_`{|}~])(?=\\S+$).{8,}$')),

    level: joi.string()
      .valid(...globals.levels),

    location: joi.string()
      .alphanum(),

    device_name: joi.string()
      .allow('')
  };

  static input (data, param) {
    if (param === 'new') {
      return joi.object({
        name: this.user.name.required(),
        email: this.user.email.required(),
        pass: this.user.pass.required(),
        level: this.user.level.required(),
        location: this.user.location.required(),
        device_name: this.user.device_name.required()
      }).validate(data);
    }
    else if (param === 'change') {
      return joi.object({
        name: this.user.name,
        email: this.user.email,
        pass: this.user.pass,
        location: this.user.location,
        device_name: this.user.device_name
      }).validate(data);
    }
    else if (param === 'changeadmin') {
      return joi.object({
        name: this.user.name,
        email: this.user.email,
        pass: this.user.pass,
        level: this.user.level,
        location: this.user.location,
        device_name: this.user.device_name
      }).validate(data);
    }
    else {
      return{error: 'No parameter specified!', value: {}};
    }
  }

  static output (data) {  // validate output from database for needed properties, strip everything else
    const {value, error} = joi.object({
      _id: joi.any(),
      name: joi.string(),
      email: joi.string(),
      level: joi.string(),
      location: joi.string(),
      device_name: joi.string().allow('')
    }).validate(data, {stripUnknown: true})
    return error !== undefined? null : value;
  }
}
